
#ifndef __CAMERA_SENSOR_H__
#define __CAMERA_SENSOR_H__

#include "pbrt.h"
#include "color.h"


/*
	The CameraSensor class is a very lightweight version of pbrt's existing Film class.
	Filters radiance samples onto sensor pixels via point sampling and allows the state
	of the sensor to be reset.
*/

class CameraSensor {
public:

	struct Pixel {
		Pixel() : L(0.f) {
			alpha = 0.f;
			weightSum = 0.f;
		}

		void Reset() {
			alpha = 0.0f;
			weightSum = 0.0f;
			L = Spectrum(0.0f);
		}

		Spectrum L;
		float alpha, weightSum;
	};


	CameraSensor::CameraSensor(int xres, int yres);

	~CameraSensor() {
		delete[] rgb;
		delete[] alpha;
	}

	void   AddSample(int pixelx, int pixely, const Spectrum &L, float alpha);
	float* ComputeImageRGB();
	void   ResetImage();

public:
	int xPixelCount, yPixelCount;

private:
	float *rgb;
	float *alpha;

	BlockedArray<Pixel> pixels;	

};




#endif // __CAMERA_SENSOR_H__

